@@ -4,10 +4,13 @@
 import numpy
 from scipy import interpolate
 
+from ..util._optional_deps import _JAX_LOADED
 from ..util.conversion import get_physical, physical_compatible
 from .Potential import _evaluatePotentials, _evaluateRforces
 from .SphericalPotential import SphericalPotential
 
+if _JAX_LOADED:
+    import jax.numpy as jnp
 
 class interpSphericalPotential(SphericalPotential):
     """__init__(self,rforce=None,rgrid=numpy.geomspace(0.01,20,101),Phi0=None,ro=None,vo=None)
@@ -46,6 +49,7 @@ Class that interpolates a spherical potential on a grid"""
         """
         SphericalPotential.__init__(self,amp=1.,ro=ro,vo=vo)
         self._rgrid= rgrid
+        self._rforce_jax_rgrid= rgrid if len(rgrid)>10000 else numpy.geomspace(1e-3 if rgrid[0]==0. else rgrid[0],rgrid[-1],10001)
         # Determine whether rforce is a galpy Potential or list thereof
         try:
             _evaluateRforces(rforce,1.,0.)
@@ -68,6 +72,7 @@ Class that interpolates a spherical potential on a grid"""
         self._rforce_grid= numpy.array([_rforce(r) for r in rgrid])
         self._force_spline= interpolate.InterpolatedUnivariateSpline(
             self._rgrid,self._rforce_grid,k=3,ext=0)
+        self._rforce_jax_grid= numpy.array([self._force_spline(r) for r in self._rforce_jax_rgrid])
         # Get potential and r2deriv as splines for the integral and derivative
         self._pot_spline= self._force_spline.antiderivative()
         self._Phi0= Phi0+self._pot_spline(self._rgrid[0])
@@ -95,6 +100,24 @@ Class that interpolates a spherical potential on a grid"""
         out[r < self._rmax]= self._force_spline(r[r < self._rmax])
         return out
 
+    def _rforce_jax(self,r):
+        """
+        NAME:
+           _rforce_jax
+        PURPOSE:
+           evaluate the spherical radial force for this potential using JAX,
+           which doesn't support splines, only linear interpolation.
+        INPUT:
+           r - Galactocentric spherical radius
+        OUTPUT:
+           the radial force
+        HISTORY:
+           2023-02-10 - Written - Lane (UofT)
+        """
+        if not _JAX_LOADED: # pragma: no cover
+            raise ImportError("Making use of _rforce_jax function requires the google/jax library")
+        return jnp.interp(r,self._rforce_jax_rgrid,self._rforce_jax_grid)
+
     def _r2deriv(self,r,t=0.):
         out= numpy.empty_like(r)
         out[r >= self._rmax]= -2.*self._total_mass/r[r >= self._rmax]**3.
