@@ -8,7 +8,7 @@ import numpy
 from ..util import config, conversion, plot
 from ..util.conversion import (physical_compatible, physical_conversion,
                                potential_physical_input)
-from .Potential import PotentialError, flatten
+from .Potential import PotentialError, flatten, potential_positional_arg
 
 
 class linearPotential:
@@ -172,12 +172,16 @@ class linearPotential:
            2020-04-22 - Don't turn on a parameter when it is False - Bovy (UofT)
 
         """
-        if not ro is False: self._roSet= True
-        if not vo is False: self._voSet= True
-        if not ro is None and ro:
-            self._ro= conversion.parse_length_kpc(ro)
-        if not vo is None and vo:
-            self._vo= conversion.parse_velocity_kms(vo)
+        if not ro is False:
+            self._roSet= True
+            ro= conversion.parse_length_kpc(ro)
+            if not ro is None:
+                self._ro= ro
+        if not vo is False:
+            self._voSet= True
+            vo= conversion.parse_velocity_kms(vo)
+            if not vo is None:
+                self._vo= vo
         return None
 
     @potential_physical_input
@@ -302,6 +306,7 @@ class linearPotential:
                          xlabel=r"$x/x_0$",ylabel=r"$\Phi(x)$",
                          xrange=[min,max])
 
+@potential_positional_arg
 @potential_physical_input
 @physical_conversion('energy',pop=True)
 def evaluatelinearPotentials(Pot,x,t=0.):
@@ -345,6 +350,7 @@ def _evaluatelinearPotentials(Pot,x,t=0.):
     else: #pragma: no cover
         raise PotentialError("Input to 'evaluatelinearPotentials' is neither a linearPotential-instance or a list of such instances")
 
+@potential_positional_arg
 @potential_physical_input
 @physical_conversion('force',pop=True)
 def evaluatelinearForces(Pot,x,t=0.):
