@@ -105,9 +105,10 @@ void bovy_rk4(void (*func)(double t, double *q, double *a,
       *err= -10;
       interrupted= 0; // need to reset, bc library and vars stay in memory
 #ifdef USING_COVERAGE
-      __gcov_flush();
-#endif
+      __gcov_dump();
 // LCOV_EXCL_START
+      __gcov_reset();
+#endif
       break;
 // LCOV_EXCL_STOP
     }
@@ -214,9 +215,10 @@ void bovy_rk6(void (*func)(double t, double *q, double *a,
       *err= -10;
       interrupted= 0; // need to reset, bc library and vars stay in memory
 #ifdef USING_COVERAGE
-      __gcov_flush();
-#endif
+      __gcov_dump();
 // LCOV_EXCL_START
+      __gcov_reset();
+#endif
       break;
 // LCOV_EXCL_STOP
     }
@@ -545,9 +547,10 @@ void bovy_dopr54(void (*func)(double t, double *q, double *a,
       *err= -10;
       interrupted= 0; // need to reset, bc library and vars stay in memory
 #ifdef USING_COVERAGE
-      __gcov_flush();
-#endif
+      __gcov_dump();
 // LCOV_EXCL_START
+      __gcov_reset();
+#endif
       break;
 // LCOV_EXCL_STOP
     }
